package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````\"4``#0````DX0```````#0`(``+
M`"@`&P`:``8````T````-````#0```!@`0``8`$```0````$`````P```)0!
M``"4`0``E`$``!,````3````!`````$````!````````````````````#!$`
M``P1```$`````!````$`````(````"`````@```X5@``.%8```4`````$```
M`0````"`````@````(```+!.``"P3@``!``````0```!````W-T``-S=``#<
MW0``/`(``%`"```&`````!````(```#DW0``Y-T``.3=`````0````$```8`
M```$````!````*@!``"H`0``J`$``$0```!$````!`````0```!0Y71D<,``
M`'#```!PP```%`$``!0!```$````!````%'E=&0`````````````````````
M``````8````0````4N5T9-S=``#<W0``W-T``"0"```D`@``!`````$````O
M;&EB+VQD+6QI;G5X+G-O+C(```0````4`````P```$=.50"$:9D*^5P'CP,J
M<[JZ;S?(CPXRKP0````0`````0```$=.50```````P````(`````````$0``
M`$4````(````"``````0$`0E0`2`*`$`!:"&`(2`@0`""R@$"#B`$D&*```(
M`````$4```!(````2P```$P```!4````50```%8`````````6````%D```!:
M````7````%T```!?``````````````!NQ=\?SMY'+6M_FGPNQ9NVU&34?"'_
MY`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RRZXY)\^J%L8)E/PYMK"4/69Z_,
M9D)%U>R)!W#3,V+;[16,)<P,.I<+6>CM['^IG)O@IP(*:QJ>4*/@^TD`````
M````````````````M`(`````````````$@```!X"`````````````!(````)
M`@`````````````2````Y```````````````$@```)8``````````````!(`
M``!=`0`````````````2````RP$`````````````$@```$0"````````````
M`!(```#Z```````````````2`````0``````````````(````"X"````````
M`````!(```")`@`````````````2````UP(`````````````$@```"L!````
M`````````!(````;`0`````````````2````#0$`````````````$@```-(!
M`````````````!(```#]`0`````````````2````$```````````````(```
M`'L!`````````````!(```#I```````````````2````GP(`````````````
M$@```"P``````````````"````!3`@`````````````2````#P(`````````
M````$@```)`"`````````````!(```!&```````````````2````8P``````
M````````%@```$T!`````````````!(```!V```````````````2````TP``
M````````````$@```(<``````````````!(```"Q`0`````````````2````
M;`(`````````````$0```*8"`````````````!(```#P`0`````````````2
M````V@$`````````````$@```)L#`````````````!(```"W````````````
M```2````F`(`````````````$@```,\"`````````````!$```#"`0``````
M```````2````/P$`````````````$@````("`````````````!(```!T`0``
M```````````2````[@``````````````$@```.D"`````````````!(```#W
M`0`````````````2````Z0$`````````````$@```%("`````````````!(`
M```E`@`````````````2````X0$`````````````$@```*(`````````````
M`!(```!H`0`````````````2````-@(`````````````$@```,T"````````
M`````!$```!S`@`````````````2````Q0(`````````````$@```,8`````
M`````````!$```"&`0`````````````1````-`$`````````````$@```%0`
M`````````````!(```"[`0`````````````2````6@(`````````````$@``
M`*D!`````````````!(```"M`@`````````````2````>@(`````````````
M(@```*0!`````````````!(```"D`P``8$(``,4````2``X`Z@,``&`Y``#Q
M!@``$@`.`&<"``"P(P``-`(``!(`#@`4`P``@"X```4````2``X`.0,``&!`
M``#_`0``$@`.`!`$``"0+@``%0(``!(`#@#0`P``&.`````````0`!@`)0,`
M`+`P```R````$@`.`$\#```@-@``80```!(`#@"5`0``!(````0````1`!``
MO0,``'!Q```7`@``$@`.`,@#``"`+0``-@```!(`#@#E`P``+.`````````0
M`!@`_@,``&`X``#U````$@`.`"<$``"0-@``,P```!(`#@"P`P```.``````
M```0`!<`<P,``/`P```D`0``$@`.`/<#```8X````````!``%P`=!```%.``
M``0````1`!<`M@,``/`E```L````$@`.`-P#``#@<```@P```!(`#@"R`P``
M`.`````````@`!<`,@,```"````$````$0`0`(D#```P.```*P```!(`#@!=
M`P``P"T``+<````2``X`?P,``)!S``!0`@``$@`.`"\$```@,@``_`,``!(`
M#@``7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F
M;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A
M<`!?24]?<W1D:6Y?=7-E9`!E>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U
M<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U;FQI;FL`;65M;6]V90!S=')T
M;VL`<W1R;&5N`')M9&ER`')E860`<W1R<W1R`&UK9&ER`%]?=F9P<FEN=&9?
M8VAK`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]F
M<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R<@!M
M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&]P96YD:7(`9V5T=6ED`&%C
M8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`<W1R;F-M<`!?
M7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9F%I;`!L
M:6)P97)L+G-O+C4N,S@`;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`<&%R
M7V)A<V5N86UE`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N
M=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA
M7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`
M<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L
M:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXQ+C,`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?
M,BXR`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?
M,BXQ`$=,24)#7S(N,`````(``@`"``$``0`!``,`!``!``$``@`"``4``0`!
M``$``@`"``$``0`"``(``0`&``0``@`!``$``0`!``$``0`'``(``@`"``(`
M`@`!``(``@`"``$``@`"``$`"``"``(`!@`"``(``0`!``0``@`"``(``0`!
M``$``0`"``D``P`"``H``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0````$`"0`*`P``$`````````!S
M'VD)```*`#P$```0````M)&6!@``"0!(!```$````!1I:0T```@`4P0``!``
M```2:6D-```'`%T$```0````LY&6!@``!@!G!```$````'(9:0D```4`<@0`
M`!````!T&6D)```$`'X$```0````$6EI#0```P"*!```$````!!I:0T```(`
ME`0```````#<W0``"````.#=```(````_-\```@````$X```"````!3@```(
M````S-\```8)``#0WP``!@H``-3?```&$P``V-\```87``#<WP``#AP``.#?
M```&'0``Y-\```8>``#HWP``!B(``.S?```&*0``\-\```8[``#TWP``!CP`
M`/C?```&0P``\-X```<!``#TW@``!P(``/C>```'`P``_-X```<$````WP``
M!P4```3?```'!@``"-\```<'```,WP``!P@``!#?```'"P``%-\```<,```8
MWP``!PT``!S?```'#@``(-\```</```DWP``!Q```"C?```'$0``+-\```<2
M```PWP``!Q0``#3?```'%0``.-\```<6```\WP``!Q@``$#?```'&0``1-\`
M``<:``!(WP``!QL``$S?```''P``4-\```<@``!4WP``!R$``%C?```'(P``
M7-\```<D``!@WP``!R4``&3?```')@``:-\```<G``!LWP``!R@``'#?```'
M*@``=-\```<K``!XWP``!RP``'S?```'+0``@-\```<N``"$WP``!R\``(C?
M```',```C-\```<Q``"0WP``!S(``)3?```',P``F-\```<T``"<WP``!S4`
M`*#?```'-@``I-\```<W``"HWP``!SD``*S?```'.@``L-\```<]``"TWP``
M!SX``+C?```'/P``O-\```=```#`WP``!T$``,3?```'0@``R-\```=$````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z!<&``"!P]N^``"+@^P```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@_____Z,0````:`@```#IT/____^C%````&@0
M````Z<#_____HQ@```!H&````.FP_____Z,<````:"````#IH/____^C(```
M`&@H````Z9#_____HR0```!H,````.F`_____Z,H````:#@```#I</____^C
M+````&A`````Z6#_____HS````!H2````.E0_____Z,T````:%````#I0/__
M__^C.````&A8````Z3#_____HSP```!H8````.D@_____Z-`````:&@```#I
M$/____^C1````&AP````Z0#_____HT@```!H>````.GP_O___Z-,````:(``
M``#IX/[___^C4````&B(````Z=#^____HU0```!HD````.G`_O___Z-8````
M:)@```#IL/[___^C7````&B@````Z:#^____HV````!HJ````.F0_O___Z-D
M````:+````#I@/[___^C:````&BX````Z7#^____HVP```!HP````.E@_O__
M_Z-P````:,@```#I4/[___^C=````&C0````Z4#^____HW@```!HV````.DP
M_O___Z-\````:.````#I(/[___^C@````&CH````Z1#^____HX0```!H\```
M`.D`_O___Z.(````:/@```#I\/W___^CC````&@``0``Z>#]____HY````!H
M"`$``.G0_?___Z.4````:!`!``#IP/W___^CF````&@8`0``Z;#]____HYP`
M``!H(`$``.F@_?___Z.@````:"@!``#ID/W___^CI````&@P`0``Z8#]____
MHZ@```!H.`$``.EP_?___Z.L````:$`!``#I8/W___^CL````&A(`0``Z5#]
M____H[0```!H4`$``.E`_?___Z.X````:%@!``#I,/W___^CO````&A@`0``
MZ2#]____H\````!H:`$``.D0_?___Z/$````:'`!``#I`/W___^CR````&AX
M`0``Z?#\____H\P```!H@`$``.G@_/___Z/0````:(@!``#IT/S___^CU```
M`&B0`0``Z<#\____H]@```!HF`$``.FP_/___Z/<````:*`!``#IH/S___^C
MX````&BH`0``Z9#\____H^0```!HL`$``.F`_/___Z,4`0``9I``````````
M`(U,)`2#Y/#_<?Q5B>57B<]64^A9`@``@<,=NP``48/L+(M!!(E%U(M!"(E%
MT&6A%````(E%Y#'`C4704(U%U%!1Z$K___^+@^@```"#Q`Q04/^S``$``.C4
M40``BX,,`0``@\00@#@`#X07`0``BX/X````98L`@(BZ`@```XL'C7`#@\`$
MB77,/?___S\/AW,!``"#[`S!X`)0Z*#^__^+==2+/X/$$(G!B8-``0``BP:)
M`8V#!Z/__XE!!(N#,`$``(E!"(V#"J/__XE!#(/_`0^.0P$``(E-R(U&!(U1
M$(TTOHUT)@"+"(/`!(/"!(E*_#G&=?&+3<B#QP.#[`R-@SQ.___'!+D`````
M:@!1_W7,4/^S1`$``.BQ^___@\0@A<`/A(\```"#[`S_LT0!``"-?>#H5?W_
M_XGZB<:-@\.A___H)@(``(/$$(7`='Z#[`S_LT0!``#H4?O__^A\_/__@\00
MBT7D92L%%`````^%N````(UE\(GP65M>7UV-8?S#Z/;[__^)@T0!``"%P`^$
MC0```(/L#%#H7_S__XN#^````(/$$&6+$,:"E@4```#IN_[__X/L#/^S1`$`
M`.AI^___@\00Z5O___^+@SP!``"%P'01@^P,4.C.'```@\00Z6?___^)^HV#
M>*'__^AY`0``B8,\`0``A<`/A$S____KTE!0C8-SH?___[,0`0``4.@5_?__
MOP0```#IV/[__X/L#&H!Z+']___H+%```&:09I!FD&:09I!FD#'M7HGA@^3P
M4%12Z!@```"!P^2X``!J`&H`45;_LQ@!``#H2?W___2+'"3#9I!FD(L<),-F
MD&:09I!FD&:09I#HX````('"K[@``(V*-`$``(V"-`$``#G(=!V+@O````"%
MP'0358GE@^P44?_0@\00R<,NC70F`,.-M"8`````Z*````"!PF^X``!5B>53
MC8HT`0``C8(T`0``@^P$*<B)P\'H'\'[`@'8T?AT%(N2]````(72=`J#[`A0
M4?_2@\00BUW\R<,NC;0F`````)!5B>53Z%?___^!PQNX``"#[`2`NS0!````
M=2>+@Q0!``"%P'01@^P,_[,@`0``Z*W\__^#Q!#H-?___\:#-`$```&+7?S)
MPRZ-M"8`````D.E;____BQ0DPV:09I!FD)!55U93Z/?^__^!P[NW``"#[!R)
M5"0(A<`/A+(```")P8N#"`$``(L0A=(/A*`````/M@&$P'0$/#UU53'MBS*%
M]G0\B50D#(GPB=:)3"0$B<>-M"8`````@^P$5?]T)`Q7Z)K[__^#Q!"%P'4&
M@#PO/70UBWX$@\8$A?]UVXG^@\0<B?!;7E]=PXVT)@````")S0^V10&#Q0&$
MP'0$/#UU\2G-ZYB-=@"+5"0,B?B)]XG&BT0D""G7C70N`<'_`HDX@\0<B?!;
M7E]=PRZ-="8`@\0<,?9;B?!>7UW#C70F`%:)QE/H%_[__X'#V[8``(/L?&6A
M%````(E$)'0QP(U$)!105NB'^O__@\00A<!U.(M4)!R!X@#P``"!^@!```!T
M"('Z`*```'4@@^P(:@)6Z/OX__^#Q!"%P`^4P`^VP.L(C;8`````,<"+5"1L
M92L5%````'4&@\1T6U[#Z(Y-```NC;0F`````(VV`````%575HG&4^B%_?__
M@<-)M@``@>R,````9:$4````B40D?#'`A?9T!8`^`'4DBT0D?&4K!10````/
MA3P!``"!Q(P```!;7E]=PRZ-M"8`````@^P,5NB7^/__@\00B<>%P'3*@^P,
M5^C%^/__@\00A<`/A+H```"`>!,NC5`3=0F`>@$`=-V-=@"`>!,N#X2^````
MB50D#(/L#%;HL?C__XM4)!R)Q8D4)(E4)!SHG_C__XU$!0*)!"3H$_G__XG%
M6(V#)*'__UJ+5"044E90:O]J`57HF/G__X/$&(U$)"105>CJ]___@\00@_C_
M=!"+1"0L)0#P```]`$```'1R@^P,5>A9^/__@\00@^P,5>B=]___@\00@^P,
M5^@1^/__@\00A<`/A4S___^-M@````"#[`Q7Z&?X__^)-"3HO_C__X/$$.GC
M_O__C;0F`````(!Z`2X/A3C___^`>@(`#X3^_O__Z2G___^-M"8`````B>CH
MB?[__^N1Z`),``!FD%6)Q5=6B=93Z`/\__^!P\>T``"#[#AEH10```")1"0H
M,<`QP(`Z/0^4P`'&5NB>]___@\00B40D!(U4)!B)Z.C,_/__A<`/A`0!``"#
M[`R)QU#H>??__XM,)!2#Q!`YR`^#R@```(M$)!C!X`*)1"0(BX,(`0``B00D
M#[9%`(3`#X2:`0``/#T/A)(!``")Z`^V4`&#P`&$TG0%@/H]=?`IZ(L,)(M\
M)`B#[`R+5"00`SF-1!`"4.B4]___@\00B0>%P'1*BPPDBWPD"(L!C4T!BQ0X
M#[9%`(@"/#UT'83`=0KK%XUT)@`\/70/#[8!@\(!@\$!B`*$P'7MQ@(],<`/
MM@P&B$P"`8/``83)=?&+1"0<92L%%`````^%$P$``(/$+%M>7UW#+HVT)@``
M```QP(VV``````^V%`:(%`>#P`&$TG7RZ\<NC;0F`````(N#"`$``(L0B00D
MBSJ%_P^$P@```#'_+HVT)@````"0B?B#QP&+#+J%R77TC02%#````(N+.`$`
M`(7)=6.)5"0,@^P,4,>#.`$```$```#HK/;__X/$$(G!A<`/A%[___^-!+T`
M````@^P$B40D#%"+5"044E&)3"0<Z/'V__^+1"00BTPD'(/$$(D(QT2Y!```
M``")?"08Z8W^__^-=@"#[`A04NBF]/__B<&+1"00@\00B0B%R0^$`O___XT$
MO0````")1"0(Z\*-M@`````QP.E[_O__N`@````Q_^E0____Z,A)```NC;0F
M`````%57B==6B<93Z,/Y__^!PX>R``"![#`0``!EH10```")A"0@$```,<!H
M_P\``(V#*J'__XUL)"154.@R]O__@\00A<!^$(G"C4#_@'P4&P!U1X7`=3N+
M@_@```"#[`175F7_,.A(]/__@\00BX0D'!```&4K!10```!U3H'$+!```%M>
M7UW#+HVT)@````!FD(G"C;8`````@^P$4HE4)!1J+U7H&/;__X/$$(7`=*:+
M5"0,BX/X````4E569?\PZ/ST__^#Q!#KHNCR2```9I!64^CY^/__@<.]L0``
M@^P$C8.`X?__B[/X````4(V#.:'___^S_````%!E_S;HWO7__UB-@^2B__]:
M:@!04(V#?&'__U"-@U6A__]09?\VZ"ST__^#Q"1;7L.-M@````!3Z)KX__^!
MPUZQ``"#[`B-@X#A__]0C8,YH?___[/\````4(N#^````&7_,.A_]?__@\08
M6\,NC;0F`````&:053'M5U93Z%7X__^!PQFQ``"![!P@``!EH10```")A"0,
M(```,<#H5?+__X/L"(V3-:'__U)0C8-JH?__4&@!$```:@&-="0F5NCR]/__
M@\0<:``0``"-O"03$```5U;HG/3__X/$$(7`>"J#[`R)QHU``5#H)_3__X/$
M$(G%A<!T$X/L!%974.B#\___QD0U``"#Q!"+A"0,(```92L%%````'4-@<0<
M(```B>A;7E]=P^B91P``+HVT)@````"0Z3O___\NC;0F`````(UV`%575E/H
MA_?__X'#2[```('LG!```&6A%````(F$)(P0```QP(U$)"R+O"2P$```BZPD
MM!```(E$)!2)PHV#>*'__^A)^/__@^P(:B^)QE?HW/'__X/$$(7`=#6-@X&A
M__^)^N@8^___B?B+E"2,$```92L5%`````^%D@$``('$G!```%M>7UW#C;0F
M`````(/L#%7H)_3__UI9C8N.H?__B4PD%%%0Z&3S__^#Q!"-BY"A__^)Q8V#
MF:+__XE$)!B%[726@'T``(E,)!P/A.<````NC70F`(7V=!6#[`A55N@*]/__
M@\00A<`/A*0```"#[`Q5Z%;R__^#Q!")PHU$!?\YQ7(3ZR2-M"8`````Q@``
M@^@!.<5T!8`X+W3Q@^P,5>@H\O__@\00B<*)5"00@^P,5^@6\O__BU0D((/$
M$(U$`@$]_P\```^'"____X/L!%?_="0D5?]T)"AH`!```&H!C:PDJ````%7H
M__+__X/$&/]T)!Q5Z%+Q__^#Q!"%P'40BT0D/"4`\```/0"```!T2X/L"/]T
M)!1J`.AM\O__@\00B<6%P`^$J_[__X!]```/A1[___^%]G0%@#XN=!6Z`0``
M`(VK=J'__^E:____+HUT)@"`?@$`=+?KXX/L"&H!5>C5\/__@\00A<!UHXGJ
MC8.!H?__Z('Y__^#[`Q5Z+CR__^#Q!#I6O[__^AK10``+HVT)@````"-=@!6
M4^AI]?__@<,MK@``@^P,BW0D&&HO5NA$\/__A<"-4`$/1?*)-"3H=/+__X/$
M%%M>PRZ-M"8`````C;8`````55=64^@G]?__@</KK0``@>P<$```9:$4````
MB80D#!```#'`B[0D,!```(7V#X2=````@#X`#X24````@^P,5NBK\/__@\00
MC4@!B<(QP('Y`!```'==C6PD#(/Y!`^#A````(7)#X64````C405_SG%<A;K
M&2Z-M"8`````9I#&``"#Z`$YZ'0%@#@O=/&#[`AJ+U7HAN___X/$$(7`="\Y
MQ7,#Q@``@^P,5>BO\?__@\00BY0D#!```&4K%10```!U6X'$'!```%M>7UW#
MD(/L#(V#=J'__U#H@?'__X/$$.O0C70F`(M$#OR)[XE$#`B)T<'I`O.EZ6[_
M__]FD`^V!HA$)`SVP0(/A%S___\/MT0._F:)1`P*Z4W____H_$,``"Z-M"8`
M````C70F`%575N@!$0``@<:\K```4X/L+&6A%````(E$)!PQP(U<)!B+K@@!
M``"-OI*A__^)VHGXZ,GT__^%P'0NBU0D&(M%`(T$D(M0!(D0A=)TX&:0BU`(
M@\`$B1"%TG7TB=J)^.B;]/__A<!UTHNN"`$``(V^FZ'__XG:B?CH@O3__X7`
M="^+5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.A3]/__
MA<!UT8NN"`$``(V^HZ'__XG:B?CH.O3__X7`="^+5"08BT4`C020BU`$B1"%
MTG3@C78`BU`(@\`$B1"%TG7TB=J)^.@+]/__A<!UT8NN"`$``(V^K*'__XG:
MB?CH\O/__X7`="^+5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7T
MB=J)^.C#\___A<!UT8V&LZ'__XN^"`$``(D$)(L$)(G:Z*;S__^%P'0LBU0D
M&(L'C020BU`$B1"%TG3@BU`(@\`$B1"%TG7TBP0DB=KH>O/__X7`==2+K@@!
M``"-OL.A__^)VHGXZ&'S__^%P'0VBU0D&(M%`(T$D(M0!(D0A=)TX"Z-M"8`
M````9I"+4`B#P`2)$(72=?2)VHGXZ"OS__^%P'7*C89XH?__B[X(`0``B40D
M!(M$)`2)VN@,\___A<!T,XM4)!B+!XT$D(M0!(D0A=)TWXVV`````(M0"(/`
M!(D0A=)U](M$)`2)VNC9\O__A<!US8V&SZ'__XN^"`$``(E$)`R+1"0,B=KH
MNO+__X7`=#&+5"08BP>-!)"+4`2)$(72=-^-="8`BU`(@\`$B1"%TG7TBT0D
M#(G:Z(GR__^%P'7/C8;9H?__B[X(`0``B40D"(M$)`B)VNAJ\O__A<!T,8M4
M)!B+!XT$D(M0!(D0A=)TWXUT)@"+4`B#P`2)$(72=?2+1"0(B=KH.?+__X7`
M=<^+K@@!``"-ON.A__^)VHGXZ"#R__^%P'0UBU0D&(M%`(T$D(M0!(D0A=)T
MX"Z-M"8`````D(M0"(/`!(D0A=)U](G:B?CHZ_'__X7`=<N+K@@!``"-OH&A
M__^)VHGXZ-+Q__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0
MA=)U](G:B?CHH_'__X7`==&)VHV&[:'__^B2\?__A<!T"XG"BT0D".AS]/__
MB=J-AOZA___H=O'__X7`=`V)PHV&$*+__^A5]/__B=J-AANB___H6/'__XG"
MA<!T*XM$)`3H.?3__XM$)!QE*P44````=3.+!"2#Q"R-ECRB__];7E]=Z1?T
M__^)VHV&*Z+__^@:\?__A<!TS8G"BT0D#.C[\___Z\#H]#\``(UT)@#H``T`
M``6_J```@^P<98L5%````(E4)`PQTHU4)`B-@,^A___HU_#__X7`="L/MA"`
M^C`/E,"$T@^4P@G0@_`!#[;`BU0D#&4K%10```!U#(/$',.-="8`,<#KY^B/
M/P``+HVT)@````"-M"8`````4^B*[___@<-.J```@^P(C40D%%#_="04BX,$
M`0``:@'_,.BYZO__QP0D_P```.C-[/__+HVT)@`````NC70F`%57B<=64^A%
M[___@<,)J```@>PL``$`B40D!&6A%````(F$)!P``0`QP&H":@!J`%?H:NS_
M_X/`_X/2_XE$)!B+="08B=>)5"0<P?\?,?@I^#'2)?__```Q^C'X*?@9^HM\
M)!PIQAG7@\00C6PD%(7_#XBU````+HVT)@````"0:@!75O]T)!#H$^S__X/$
M$"'0@_C_#X2L````@^P$:`@``0!5_W0D$.BCZ?__@\00@_C_#X1_````@_@'
M=E*-1`7X.>AR2HT5)`$``.L)9I"#Z`$YZ'(YBPP:.0AU\HN+*`$``#E(!'7G
M*>B9`?`1^HN,)!P``0!E*PT4````=5:!Q"P``0!;7E]=PRZ-="8`@<8``/__
M@]?_B?")^C4``/__]]()T`^%5/___[C_____NO_____KN(/L#(V#2Z+__U#H
M>?[__X/L#(V#/J+__U#H:O[__^CE/0``+HUT)@!3Z.KM__^!PZZF``"#[`CH
MW.G__X/L#%#HL^G__X/$$(7`=`*+`(/$"%O#+HUT)@!55U93Z+?M__^!PWNF
M``"#["QEH10```")1"0<,<"-5"08BVPD0(V[5Z+__XGXZ(WN__^%P'0'@#@`
MB<9U(HM$)!QE*P44````#X6A````B>J#Q"R)^%M>7UWI4?'__Y"#[`A54.B&
MZ?__@\00A<!T'XM$)!QE*P44````=7*#Q"Q;7E]=PRZ-M"8`````9I"#[`Q5
MZ.?H__^)-"2)1"0<Z-OH__^+5"0<C40"`HD$).A+Z?__@\0,B<*-@XZA__]6
M4(V#F:+__U50:O]J`5*)5"0LZ,CI__^#Q""+5"0,BT0D'&4K!10````/A&'_
M___HNSP``"Z-M"8`````C78`55=64^BW[/__@<-[I0``@>S\````BX0D$`$`
M`(U\)"R)^HE$)`QEH10```")A"3L````,<"-@VZB___'A"24`````````(F$
M)(P```"-@W:A__^)A"20````C8,)HO__B80DJ````(V#<Z+__XF$)*P```"-
M@R:B__^)A"2P````C8-[HO__B80DM````(V#?Z+__XF$))@```"-@X2B__^)
MA"2<````C8-XH?__QX0DN`````````#'A"2@`````````(E$)!CH\^S__X7`
M=`F`.``/A68$``#HX>?__X/L#%#HN.?__X/$$(7`#X2]`P``BRB%[0^$LP,`
M`(/L#%7H>N?__X/$$(/L#(U$``%0Z.KG__^#Q!")Q@^V10")="0(A,!T.(V+
MC:+__XE\)`2)]XG.C78`@^P,#[;`@\4!4%9J_VH!5X/'`NA0Z/__#[9%`(/$
M((3`==V+?"0$C;0DI````(V#$*+__^L,9I"+1@2#Q@2%P'0VB?KH/^S__XG%
MA<!TZ8`X`'3DZ`_M__^%P'3;@^P,5>A2Z/__@\00B<6%P'4Y+HVT)@````"0
MC;0DC````(LNA>UT(X!]```/A-D"``")Z.C2[/__A<`/A>H```"+;@2#Q@2%
M[77=@^P,5>B7YO__6O]T)!2)QNB+YO__C;0&!`0``(DT).C\YO__B40D%(G!
MC8.2HO___W0D&%"-@Y"A__^)1"0@4(V#EZ+__U6)S5!J_VH!4>ALY___@\0H
M:,`!``!5Z*[D__^#Q!"#^/]U$.B!Y/__BP"#^!$/A<4"``"#[`A7_W0D$.CI
MYO__@\00B<6%P'1P@^P,_W0D$(M$)!S_,(V#3*/__U`Q]HN#!`$``&H!_S#H
MJ^3__X/$((N$).P```!E*P44````#X4Q!```@<3\````B?!;7E]=PXVT)@``
M``"#[`R#Q@15Z"3G__^#Q!")Q87`#X3>_O__Z0+___]FD(M$)#PE`/```#T`
M0```=8"+1"1$B40D$.C#Y?__.40D$`^%:?___XM$)#PE_P$``#W``0``#X55
M____@^P,5NC<Y?__B?J)QHV#8J+__^B-ZO__@\00A<`/A"H"``"#[`A0BT0D
M&/\PZ./Q__^)1"0@@\00A<`/A`P"``"#[`S_="0<Z!CE__^#Q!")PH/X`W9&
M@^P(C8.@HO__4(M$)!R-1!#\B50D*%#HDN;__X/$$(7`=2.+5"0<@_H$#X3D
M`@``BT0D$(!\$/LO#X35`@``C;0F`````(GZC;O/H?__B?CH^>G__X7`#X2Q
M`0``#[8`A,`/A*8!```\,`^$G@$``(V3/*+__XGXC;ODHO__Z+OL___HYN+_
M_U=0C8/$HO___W0D$/]T)!!0:O]J`5;HB^7__X/$((V#TJ+__XE$)`SK-8UT
M)@#HH^+__X,X$74]Z*GB__^#Q0&#[`Q755#_="0@_W0D(/]T)"QJ_VH!5NA*
MY?__@\0P@^P(:,`!``!6Z(GB__^#Q!"#^/]TN8/L#/]T)!#H9>/__XM$)"B)
M\N@J[/__B30DZ'+Z__^#Q!#I`O[__RZ-M"8`````9I`Q[>DY_?__+HVT)@``
M``"0BX0DF````(VT))@```"%P'0@C;8`````B?KH\>C__X7`=`6`.`!U,(M&
M!(/&!(7`=>:#[`R-JV>B__]J#>@.Y/__@\00B<:)1"0(N%,```#I(OS__XUV
M`(/L#%#HW^3__X/$$(G%A<!TONG>^___@^P(4/]T)!"+1"0<_S"-@Q"C___I
M2_W__RZ-M"8`````@^P,4(E$)!3HL_G__XM$)!2)!"3HE^3__X/$$(G&Z37]
M__\NC70F`(M$)`R+`(E$)!#IY?W__RZ-M"8`````D(/L"&H`_W0D'.BBX?__
M@\00A<`/A$G^__^)1"0,Z,[W__^)1"00B50D%(72#X@P_O__@\#V:@"#TO]2
M4(M,)!A1B4PD'.A&Y/__@\0,:@:-A"3%````4(M,)!A1B4PD'.C;X?__@\00
MBTPD#(/X!@^%[0```(&\)+T`````0T%##X7<_?__9H&\),$```!(10^%S/W_
M_VH`BT0D%(M4)!B#P,Z#TO]24%&)3"0<Z-[C__^#Q`QJ*(V\),L```!7BTPD
M&%'H=^'__X/$$(/X*`^%C0```(V#Y*+__\:$).L`````4(V#M:+__U?_="00
M_W0D$%!J_VH!5N@BX___@\0@Z>G]__^+1"0,BU`$A=(/A"/]__^#[`Q2B50D
M'.C>X?__@\00@_@##X8*_?__@^P(C8NEHO__48M4)!B-1`+\4.A:X___@\00
MBU0D#(7`#T54)!")5"00Z=O\___HSC4``(/L#(V#JJ+__U#H/_;__RZ-M"8`
M````C;0F`````%575E/HM^7__X'#>YX``(/L'&6A%````(E$)`PQP(U\)`B)
M^HNS^````&6++@^V16B(16F-@[.A___H@>;__X7`=`F`.#$/A$P!``#H;_'_
M_V6++HV#XZ+__VH#:@%05>@KX/__@\00B<6%P'0I@^P$C8/EHO__4(M%#/\P
M9?\VZ!O@__^+10R#Q!"+`/9`"D`/A3D!``"-@^JB__]J`VH!4&7_-NCFW___
M@\00B<6%P'0IB?J-@X&A___H`.;__X7`#X3H````@^P$4(M%#/\P9?\VZ,??
M__^#Q!"#[`2-@^RB__]J`5!E_S;H(-___X/$#(V3`:/__U)09?\VZ)W?__]E
MBP:)^L9`:0"-@WBA___HJ>7__X/$$(F#/`$``(G&A<!T0H/L"&C``0``5NB\
MWO__@\00C5`!@_H!=@F#^!$/A9P```"+1"0,92L%%`````^%H0```(/$'%M>
M7UW#C;0F`````(/L#/^S0`$``.B*]___@\00B8,\`0``B<:%P'6A@^P,C8.@
MH___4.CLX/__C70F`(!X`0`/A++^___II?[__RZ-M"8`````D(N#0`$``(L0
MBT4,BP#H+NK__^D5____+HVT)@````"0@^P(4&7_-N@TX/__@\00Z;/^__]0
MBX-``0``5O\PC8/$H___4.B&X/__Z+$S``"05U93Z+CC__^!PWR<``"#[!!E
MH10```")1"0,,<"-5"0(BW0D((V#SZ'__^B0Y/__A<!T&P^V$(#Z,`^4P(32
M#Y3""-!U"87V=`6`/@!U&8M$)`QE*P44````=62#Q!!;7E_#+HUT)@"#[`Q6
MZ!_N__^)QUA::B]7Z#/>__^%P(U0`0]%^HD\).ACX/__@\0,C9.2HO__:@12
M4.@AX/__@\00A<!UJ8M$)`QE*P44````=0V#Q!")\%M>7^EPY?__Z.LR``"+
M!"3#BS0DPV:0D%57B<=64X'L'`,``(E$)&2-C"20````C:PD$`$``&6A%```
M`(F$)`P#``")^(U8.(V$)(@```")1"0@+HUT)@"+<P2+`S'_QT0D'``````Q
MT@M4)!S'0?P`````@\$0#\B)0>B)\`GZB70D",'H",'N&#'_B70D&(MT)`@)
M^H/#"(E$)!"+1"00P>88B5'T)0#_```+1"08QT0D#``````)\(MT)`C'1"04
M`````,'F"('F``#_``GPB4'P.>EU@(N<)(P```"+C"2(````B[PD^````(NL
M)/P```")7"04BYPDE````(E,)!"+C"20````B5PD'(M<)"")?"0(BX0D\```
M`('#$`(``(EL)`R+E"3T````C:PDF````(E,)!B+M"0``0``B5PD*(N\)`0!
M``#K$XUV`(M,)""+7"0DB4PD&(E<)!R+30"+702#Q0B)3"0@,TTH,<B)7"0D
M,T0D$#-=+(G!B70D$#':,=LS5"04`<&)?"04#ZS0'XG?BU0D#(E=;(M<)!0)
MP8E-:(G.BTPD$(E<)`R+7"0<BT0D"(E,)`B)7"04BTPD&(M<)"B)3"00.=T/
MA7O___^+="1DBTX0BSZ+1@B+7A2+;@2+5@R)3"00BTX<B40D.(GXB5PD%(M>
M(,'@!8E,)$2)^0^LZ1N)7"1HBUPD:`G(`YPDB````(E4)#R)V8M6&(MV)('!
MF7F"6@'(B50D0(M,)!`S3"1`(TPD.(ET)&PS3"1``<@QTC')B40D((M$)#B)
M5"0DBU0D/(G#B=;!XQX/I,8>#ZS0`L'J`@G#"=:)7"08B70D'(E<)"B+7"1`
M`YPDD````(M$)!")3"0LB=F+7"0DB7PD,('!F7F"6C-$)"B);"0TB<Z+3"0@
M(?@S1"00`<:+;"0TB<@/K-D;P>`%B>N)Z@G(`<8Q_\'J`HE\)`R+?"0PB70D
M"`^D^QZ)^8GXBWPD),'A'HG>#ZSH`@G6B<N+5"00"<.)]8M$)!@Q]@.4))@`
M``")="14B=&)7"10@<&9>8):,=@C1"0@,T0D*`'!B5PD2(M<)`R)SHM,)`B)
M;"1,B<@/K-D;P>`%"<@!QC')B70D&(MT)"")3"0<B?F)\@^D\1[!XAX/K/X"
MB=#![P*)R@GP"?HQ_XE$)%B)?"1<BUPD*(MT)$@#G"2@````B40D*(G9BUPD
M'(M\)`R)5"0L@<&9>8):,<:+1"0((?`S1"10`<&)SHM,)!B)R`^LV1O!X`4)
MR`'&,<F+1"08B70D((MT)`B)3"0DB?D/I/$>B?(/K/X"P>\"P>(>B<V)^XG7
M"=T)]XM<)%"+="0HB>HQ[0.<)*@```")?"1(B=F+7"0DB7PD*('!F7F"6C'^
MBWPD'(E4)"PA\#-$)%B);"1,`<&)SHM,)"")R`^LV1O!X`4)R`'&,<F)="0(
MBW0D&(E,)`R)^8GR#Z3Q'L'B'@^L_@*)T(G*B?'![P*)QHG[B=<)S@G?B?`Q
M]HE$)%")="14BUPD6(MT)"@#G"2P````B40D*(G9BUPD#(E\)"R!P9EY@EHQ
MQHM$)""+?"0D(?`S1"1(`<&)SHM,)`B)R`^LV1O!X`4)R`'&,<F)="08BW0D
M((E,)!R)^8GR#Z3Q'L'B'@^L_@*)T,'O`HG*B?&)^XG&B=<)S@G?BUPD2(GP
MB?J)="18,?^+="0H`YPDN````(E$)"B)V8M<)!R)?"1<@<&9>8):,<:+1"0(
MBWPD#(E4)"PA\#-$)%`!P8G.BTPD&(G(#ZS9&\'@!0G(`<8QR8ET)""+="0(
MB4PD)(GY#Z3Q'HGR#ZS^`L'O`L'B'HG-B?N)UPG="?>)ZC'MB7PD2(EL)$R+
M7"10BW0D*`.<),````")?"0HBT0D&(G9BUPD)(E4)"R!P9EY@EHQ_HM\)!PA
M\#-$)%@!P8G.BTPD((G(#ZS9&\'@!0G(`<8QR8ET)`B+="08B4PD#(GYB?(/
MI/$>P>(>#ZS^`HG0B<J)\<'O`HG&B?N)UPG."=^+7"18B?`Q]@.<),@```")
M?"0LB70D5(MT)"B)V8'!F7F"6HM<)`R+?"0DB40D4#'&B40D*(M$)"`A\#-$
M)$@!P8G.BTPD"(G(#ZS9&\'@!0G(`<8QR8ET)!B+="0@B4PD'(GYB?(/I/$>
MP>(>#ZS^`HG0P>\"B<J)\8G[B=>)Q@G?"<Z)^C'_B?")="18B7PD7(M<)$B+
M="0H`YPDT````(E$)"B)V8M<)!R+?"0,B50D+('!F7F"6C'&BT0D""'P,T0D
M4`'!B<Z+3"08B<@/K-D;P>`%"<@!QC')BT0D&(ET)""+="0(B4PD)(GY#Z3Q
M'HGR#ZS^`L'O`L'B'HG-B?N)UPG="?>+7"10BW0D*(GJ,>T#G"38````B7PD
M2(G9BUPD)(E\)"B!P9EY@EHQ_HM\)!R)5"0L(?`S1"18B6PD3`'!B<Z+3"0@
MB<@/K-D;P>`%"<@!QC')B70D"(MT)!B)3"0,B?F)\@^D\1[!XAX/K/X"B=")
MRHGQP>\"B<:)^XG7"<X)WXGP,?:)1"10B70D5(M<)%B+="0H`YPDX````(E$
M)"B)V8M<)`R)?"0L@<&9>8):,<:+1"0@BWPD)"'P,T0D2`'!B<Z+3"0(B<@/
MK-D;P>`%"<@!QC')B70D&(MT)"")3"0<B?F)\@^D\1[!XAX/K/X"B=#![P*)
MRHGQB?N)QHG7"<X)WXM<)$B)\(GZB70D6#'_BW0D*`.<).@```")1"0HB=F+
M7"0<B7PD7('!F7F"6C'&BT0D"(M\)`R)5"0L(?`S1"10`<&)SHM,)!B)R`^L
MV1O!X`4)R`'&,<F)="0@BW0D"(E,)"2)^0^D\1Z)\@^L_@+![P+!XAZ)S8G[
MB=<)W0GWB>HQ[8E\)$B);"1,BUPD4(MT)"@#G"3P````B7PD*(M$)!B)V8M<
M)"2)5"0L@<&9>8):,?Z+?"0<(?`S1"18`<&)SHM,)"")R`^LV1O!X`4)R`'&
M,<F)="0(BW0D&(E,)`R)^8GR#Z3Q'L'B'@^L_@*)T(G*B?'![P*)QHG[B=<)
MS@G?BUPD6(GP,?8#G"3X````B7PD+(ET)%2+="0HB=F!P9EY@EJ+7"0,BWPD
M)(E$)%`QQHE$)"B+1"0@(?`S1"1(`<&)SHM,)`B)R`^LV1O!X`4)R`'&,<F)
M="08BW0D((E,)!R)^8GR#Z3Q'L'B'@^L_@*)T,'O`HG*B?&)^XG7B<8)WPG.
MB?HQ_XGPB70D6(E\)%R+7"1(BW0D*`.<)``!``")1"0HB=F+7"0<BWPD#(E4
M)"R!P9EY@EHQQHM$)`@A\#-$)%`!P8G.BTPD&(G(#ZS9&\'@!0G(`<8QR8M$
M)!B)="0@BW0D"(E,)"2)^0^D\1Z)\@^L_@+![P+!XAZ)S8G[B=<)W0GWBUPD
M4(MT)"B)ZC'M`YPD"`$``(E\)$B)V8M<)"2)?"0(@<&9>8):,?Z+?"0<B50D
M#"'P,T0D6(EL)$P!P8G.BTPD((G(#ZS9&\'@!0G(`<8QR8ET)"B+="08B4PD
M+(GYB?(/I/$>P>(>#ZS^`HG0B<J)\<'O`HG&B?N)UPG."=^)\#'VB40D4(ET
M)%2+7"18BW0D"`.<)!`!``")1"08B=F+7"0LB7PD'('!F7F"6C'&BT0D("'P
M,T0D2`'!B<Z+3"0HB<@/K-D;P>`%"<@!QC'_B70D"(MT)"")?"0,BWPD)(GR
MP>(>B?D/I/$>B=`/K/X"B<J)\8G&P>\""<Z)^XG7B?`Q]@G?B70D7(MT)$B)
M^@.T)!@!``"+?"1,B40D6!.\)!P!``")\8MT)!B)1"08@<&9>8):B?N+?"0<
MB50D'(/3`#'&,=>)\(MT)"B)^HM\)"PA\#-$)%`A^C-4)%0!P1'3B4PD((M,
M)`@QTHE<)"2+7"0,B<C!X`4/K-D;BUPD)`G(BTPD(`'!B?`1TXG*P>`>B4PD
M2(E4)"")^C')#Z3R'@^L_@*)3"0DBVPD),'O`HGQB5PD3(G&B?N)UPG."=^+
M7"10`YPD(`$``(GPB?J+="14BWPD'(G9$[0D)`$``('!F7F"6HE4)!R)\XMT
M)!B)1"08@],`,=<QQHGZBWPD("-4)`R)\"-$)`@S1"18,U0D7(G^`<&)^!'3
M#ZSN&S'2P>`%"?")WHG+`<,1UHE<)%")="14,?:)7"0HBUPD"(ET)"R+="0,
MB=^)]<'G'@^DW1Z)^(G?B>J)]0^L]P*+="18P>T"B?F)QXGKB=4)SPG=`[0D
M*`$``(GYBWPD7(GP$[PD+`$``(MT)!B)3"0(!:'KV6Z)^HEL)`R#T@`QSHM,
M)$B)QS';B=4Q\0'/BTPD*!'=BUPD+(G^,=*)R(GO#ZS9&\'@!8M<)"0)R`'&
M$=<QR8G:B70D2(E,)$R+3"0@B7PD7(G(#Z3*'HET)%B+="08P>`>#ZS9`HG5
MBY0D,`$``(G'P>L"BT0D4`G/BXPD-`$```G=@<*AZ]ENB7PD((/1`#'_B6PD
M)(ML)$R)RXG1`?&+="0($?N+?"1(,W0D(#'2,?`!P8G^B?@1TP^L[ALQTL'@
M!0GP`<$1TXE,)'")RC')B5PD=(M<)"R)3"14BTPD*(E4)%")VHG(#Z3*'L'@
M'@^LV0*)U<'K`HG'"<\)W8N<)#@!``")?"08B6PD'(NT)#P!``"!PZ'KV6Z)
MV8M$)%B#U@`Q_XGSBW0D"`'QBW0D(!'[,W0D&(G/BTPD4#'PB=V+7"14,=(!
MQXG($=4/K-D;B?Z+7"1,P>`%,=*)[PG(BTPD2`'&$=<QTHG(B70D*(E4)"R)
MVL'@'@^DRAX/K-D"B70D6(NT)$0!``#!ZP*)U8E\)%R)QPG=BYPD0`$```G/
MBT0D<(E\)`B!PZ'KV6Z);"0,BVPD+(/6`(G9,?^)\XMT)"`!\8MT)!@1^XM\
M)"@S="0(,=(Q\`'!B?Z)^!'3#ZSN&S'2P>`%"?`!P1'3B4PD<(G*,<F)7"1T
MBUPD5(E,)$R+3"10B50D2(G:B<@/I,H>P>`>#ZS9`HG5P>L"B<<)SPG=BXPD
M2`$``(E\)"");"0DBYPD3`$``('!H>O9;HMT)!B+1"18@],`,?\!\8MT)`@1
M^S-T)"")SXM,)$@Q\(G=BUPD3#'2`<>)R!'5#ZS9&XG^BUPD+,'@!3'2B>\)
MR(M,)"@!QA'7,=*)R(ET)%")5"14B=K!X!X/I,H>#ZS9`HET)%B+M"14`0``
MP>L"B=6)?"1<B<<)W8N<)%`!```)SXM$)'")?"08@<.AZ]ENB6PD'(ML)%2#
MU@")V3'_B?.+="0(`?&+="0@$?N+?"10,W0D&#'2,?`!P8G^B?@1TP^L[ALQ
MTL'@!0GP`<$1TXE,)'")RC')B5PD=(M<)$R)3"0LBTPD2(E4)"B)VHG(#Z3*
M'L'@'@^LV0*)U<'K`HG'"<\)W8N,)%@!``")?"0(B6PD#(N<)%P!``"!P:'K
MV6Z+="0@BT0D6(/3`#'_`?&+="08$?LS="0(B<^+3"0H,?")W8M<)"PQT@''
MB<@1U0^LV1N)_HM<)%3!X`4QTHGO"<B+3"10`<81US'2B<B)="1(B50D3(G:
MP>`>#Z3*'@^LV0*)="18B[0D9`$``,'K`HG5B7PD7(G'"=V+G"1@`0``"<^+
M1"1PB7PD(('#H>O9;HEL)"2+;"1,@]8`B=DQ_XGSBW0D&`'QBW0D"!'[BWPD
M2#-T)"`QTC'P`<&)_HGX$=,/K.X;,=+!X`4)\`'!$=.)3"1PB<HQR8E<)'2+
M7"0LB4PD5(M,)"B)5"10B=J)R`^DRA[!X!X/K-D"B=7!ZP*)QPG/"=V+C"1H
M`0``B7PD&(EL)!R+G"1L`0``@<&AZ]ENBW0D"(M$)%B#TP`Q_P'QBW0D(!'[
M,W0D&(G/BTPD4#'PB=V+7"14,=(!QXG($=4/K-D;B?Z+7"1,P>`%,=*)[PG(
MBTPD2`'&$=<QTHG(B70D*(E4)"R)VL'@'@^DRAX/K-D"B70D6(NT)'0!``#!
MZP*)U8E\)%R)QPG=BYPD<`$```G/BT0D<(E\)`B!PZ'KV6Z);"0,BVPD+(/6
M`(G9,?^)\XMT)"`!\8MT)!@1^XM\)"@S="0(,=(Q\`'!B?Z)^!'3#ZSN&S'2
MP>`%"?`!P1'3B4PD<(G*,<F)7"1TBUPD5(E,)$R+3"10B50D2(G:B<@/I,H>
MP>`>#ZS9`HG5P>L"B<<)SPG=BXPD>`$``(E\)"");"0DBYPD?`$``('!H>O9
M;HMT)!B+1"18@],`,?\!\8MT)`@1^S-T)"")SXM,)$@Q\(G=BUPD3#'2`<>)
MR!'5#ZS9&XG^BUPD+,'@!3'2B>\)R(M,)"@!QA'7,=*)R(ET)%")5"14B=K!
MX!X/I,H>#ZS9`HET)%B+M"2$`0``P>L"B=6)?"1<B<<)W8N<)(`!```)SXM$
M)'")?"08@<.AZ]ENB6PD'(ML)%2#U@")V3'_B?.+="0(`?&+="0@$?N+?"10
M,W0D&#'2,?`!P8G^B?@1TP^L[ALQTL'@!0GP`<$1TXE,)'")RC')B5PD=(M<
M)$R)3"0LBTPD2(E4)"B)VHG(#Z3*'L'@'@^LV0*)U<'K`HG'"<\)W8N,)(@!
M``")?"0(B6PD#(N<)(P!``"!P:'KV6Z+="0@BT0D6(/3`#'_`?&+="08$?LS
M="0(B<^+3"0H,?")W8M<)"PQT@''B<@1U0^LV1N)_HM<)%3!X`4QTHGO"<B+
M3"10`<81US'2B<B)="1(B50D3(G:P>`>#Z3*'@^LV0*)="18B[0DE`$``,'K
M`HG5B7PD7(G'"=V+G"20`0``"<^+1"1PB7PD(('#H>O9;HEL)"2+;"1,@]8`
MB=DQ_XGSBW0D&`'QBW0D"!'[BWPD2#-T)"`QTC'P`<&)_HGX$=,/K.X;,=+!
MX`4)\`'!$=.)3"1PB<HQR8E<)'2+7"0LB4PD5(M,)"B)5"10B=J)R`^DRA[!
MX!X/K-D"B=7!ZP*)QPG/"=V+C"28`0``B7PD&(EL)!R+G"2<`0``@<&AZ]EN
MBW0D"(M$)%B#TP`Q_P'QBW0D(!'[,W0D&(G/BTPD4#'PB=V+7"14,=(!QXG(
M$=4/K-D;B?Z+7"1,P>`%,=*)[PG(BTPD2`'&$=<QTHG(B70D*(E4)"R)VL'@
M'@^DRAX/K-D"B70D6(NT)*0!``#!ZP*)U8E\)%R)QPG=BYPDH`$```G/BT0D
M<(E\)`B!PZ'KV6Z);"0,BVPD+(/6`(G9,?^)\XMT)"`!\8MT)!@1^XM\)"@S
M="0(,=(Q\`'!B?Z)^!'3#ZSN&S'2P>`%"?`!P1'3B4PD<(G*,<F)7"1TBUPD
M5(E,)$R+3"10B50D2(G:B<@/I,H>P>`>#ZS9`HG5P>L"B<<)SPG=BXPDJ`$`
M`(E\)"");"0DBYPDK`$``('!H>O9;HMT)!B+1"18@],`,?\!\8MT)`@1^S-T
M)"")SXM,)$@Q\(G=BUPD3#'2`<>)R!'5#ZS9&XG^BUPD+,'@!3'2B>\)R(M,
M)"@!QA'7,=*)R(ET)%")5"14B=K!X!X/I,H>#ZS9`HET)'B+M"2T`0``P>L"
MB=6)?"1\B<<)W8N<)+`!```)SXM$)'")?"08@<.AZ]ENB6PD'(ML)%2#U@")
MV3'_B?.+="0(`?&+="0@$?N+?"10,W0D&#'2,?`!P8G^B?@1TP^L[ALQTL'@
M!0GP`<$1TXE,)'")RC')B5PD=(M<)$R)3"1<BTPD2(E4)%B)VHG(#Z3*'L'@
M'@^LV0*)U<'K`HG'"<\)W8N,)+@!``")?"0HB6PD+(M$)""!P:'KV6Z+="08
MBUPD7`'!BT0D>#-T)"B+;"14BY0DP`$``#'P`<&)SHM,)%B)R`^LV1O!X`4)
MR`'&,?^+1"08B7PD#(M\)%")="0(B>X/I/X>B?L/K.\"P>T"P>,>">X)^XM\
M)%R)]3'V@<*AZ]ENB5PD((G1B70D?`'!BT0D*(E<)'B)SHM,)`B);"0D,=B+
M7"0,,T0D<`'&B<C!X`4/K-D;B?L)R`'&,<F)="08BW0D6(E,)!P/I/,>B?$/
MK/X"P>\"B?")WL'A'@G^B<N+O"3,`0``B70D5#'V"<.)\HNT),@!``")V(E<
M)%"!QMR\&X^)\8MT)"B#UP")^S'_`<X1WXET)"B)?"0LBWPD((M,)%"+7"0<
MB40D2(G^B50D3(M4)%`AQ@GY(TPD"`GQBW0D*`'.BTPD&(G(#ZS9&\'@!0G(
M`<8Q_XM$)!B)="0@BW0D"(E\)"2+?"0,B?&)^\'A'@^D\QX/K/X""<XQR<'O
M`HE,)'2+3"1("?()WR'0BUPD)(E\)`PA\8ET)`@)R(M,)'@#C"30`0``B=J!
MP=R\&X^)="1PB<^+3"0@`<</I,H%B<B)5"0LP>`%B<J)1"0H#ZS:&XM<)"@)
MTXM4)!R)V`'X,<F)TXE$)"B+1"08B4PD+(G!#Z3#'L'A'@^LT`+!Z@()P0G3
MB<B)3"18,=*)7"1<"TPD"(MT)`@C3"0@B40D4(M<)"R)5"14(<8)\8MT)$@#
MM"38`0``B?")SHM,)"@%W+P;CP'&B<@/K-D;P>`%"<@!QC'_BT0D*(E\)!R+
M?"0DB70D&(MT)"")^8M<)!P/I/$>B?(/K/X"P>\"P>(>"<\QR0G6B=J)3"1\
MBTPD6(E\)`P)\8ET)`@AR(M,)%")="1X(?$)R(M,)'`#C"3@`0``@<'<O!N/
MB<^+3"08`<</I,H%B<B)5"0DP>`%B<J)1"0@#ZS:&XM<)"`)TXG8`?@QR8E$
M)""+1"0HB4PD)(M4)"R)P8MT)`B)T\'A'@^DPQX/K-`""<'!Z@*)R(E,)%@+
M3"0("=,C3"08(<8QTHE$)$@)\8MT)%`#M"3H`0``B5PD7(GPB<Z+3"0@BUPD
M)`7<O!N/B50D3`'&B<@/K-D;P>`%"<@!QC'_BT0D((E\)"R+?"0<B70D*(MT
M)!B)^8M<)"P/I/$>B?(/K/X"P>\"P>(>"<\QR0G6B=J)3"1TBTPD6(E\)`P)
M\8ET)`@AR(M,)$B)="1P(?$)R(M,)'@#C"3P`0``@<'<O!N/B<^+3"0H`<</
MI,H%B<C!X`6)5"0<B<H/K-H;B40D&(M<)!@)TXG8`?@QR8E$)!B+1"0@BU0D
M)(MT)`B)3"0<B<&)T\'A'@^DPQX/K-`""<'!Z@*)R(E,)%@+3"0("=,C3"0H
M(<8QTHE$)%`)\8MT)$@#M"3X`0``B5PD7(GPB<Z+3"08BUPD'`7<O!N/B50D
M5`'&B<@/K-D;P>`%"<@!QC'_BT0D&(E\)"2+?"0LB70D((MT)"B)^8M<)"0/
MI/$>B?(/K/X"P>\"P>(>"<\QR0G6B=J)3"1\BTPD6(E\)`P)\8ET)`@AR(M,
M)%")="1X(?$)R(M,)'`#C"0``@``@<'<O!N/B<^+3"0@`<>)R`^DR@7!X`6)
M1"0HB50D+(G*BW0D"`^LVAN+7"0H"=.+5"0<B=@!^#')B=.)1"0HBT0D&(E,
M)"R)P0^DPQ[!X1X/K-`""<'!Z@*)R(E,)%@+3"0("=,AQB-,)"`QTHE$)$@)
M\8MT)%`#M"0(`@``B5PD7(GPB<Z+3"0HBUPD+`7<O!N/B50D3`'&B<@/K-D;
MP>`%"<@!QC'_BT0D*(E\)!R+?"0DB70D&(MT)"")^0^D\1Z)\@^L_@+![P+!
MXAX)SS')"=:)3"1TBTPD6(ET)`@)\8E\)`PAR(M,)$B)="1P(?$)R(M,)'@#
MC"00`@``@<'<O!N/B<^+3"08BUPD'`''BW0D"(G:B<@/I,H%P>`%B50D)(G*
MB40D(`^LVAN+7"0@"=.+5"0LB=@!^#')B=.)1"0@BT0D*(E,)"2)P0^DPQ[!
MX1X/K-`""<'!Z@*)R(E,)%@+3"0("=,AQB-,)!@QTHE$)%`)\8MT)$@#M"08
M`@``B5PD7(GPB<Z+3"0@BUPD)`7<O!N/B50D5`'&B<@/K-D;P>`%"<@!QC'_
MBT0D((E\)"R+?"0<B70D*(MT)!B)^0^D\1Z)\@^L_@+![P+!XAX)SS')"=:)
M3"1\BTPD6(ET)`@)\8E\)`PAR(M,)%")="1X(?$)R(M,)'`#C"0@`@``@<'<
MO!N/BUPD+(MT)`B)SXM,)"B)V@''#Z3*!8G(B50D','@!8G*B40D&`^LVAN+
M7"08"=.+5"0DB=@!^#')B=.)1"08BT0D((E,)!R)P0^DPQ[!X1X/K-`""<'!
MZ@*)R(E,)%@+3"0("=,AQB-,)"@QTHE$)$@)\8MT)%`#M"0H`@``B5PD7(GP
MB<Z+3"08BUPD'`7<O!N/B50D3`'&B<@/K-D;P>`%"<@!QC'_B7PD)(M\)"R)
M="0@BW0D*(GY#Z3Q'HGR#ZS^`L'O`L'B'@G/,<D)UHE,)'2+3"18B70D"(E\
M)`P)\8ET)'"+1"08BUPD)"'(BTPD2(G:(?&+="0("<B+3"1X`XPD,`(``('!
MW+P;CXG/BTPD(`''#Z3*!8G(B50D+,'@!8G*B40D*`^LVAN+7"0H"=.+5"0<
MB=@!^#')B=.+?"0DB40D*(M$)!B)3"0LB<$/I,,>P>$>#ZS0`@G!P>H"B<B)
M3"18"TPD"`G3(<8C3"0@,=*)1"10"?&+="1(`[0D.`(``(E<)%R)\(G.BTPD
M*(M<)"P%W+P;CXE4)%0!QHG(#ZS9&\'@!0G(B?D!QHGS,?:)="0<BW0D((E<
M)!B)\@^D\1[!XAX/K/X"P>\""=8)SS')B70D"(E\)`R)="1XBT0D*(E,)'R+
M3"18BUPD'`GQ(<B+3"10B=HA\8MT)`@)R(M,)'`#C"1``@``@<'<O!N/B<^+
M3"08`<</I,H%B<B)5"0DP>`%B<J)1"0@#ZS:&XM<)"`)TXM4)"R)V`'X,<F)
MTXE$)""+1"0HB4PD)(G!#Z3#'L'A'@^LT`()P<'J`HG(B4PD2`M,)`@)TR'&
M(TPD&#'2B40D*`GQBW0D4`.T)$@"``")7"1,B?")SHM,)""+7"0D!=R\&X^)
M5"0LBU0D'`'&B<@/K-D;P>`%B=,)R`'&BT0D&#'_B70D"(G!#Z3#'HE\)`P/
MK-`"P>$>"<'!Z@*)3"18BT0D2`G3,=*+="1XBWPD#(E,)%`)R"-,)"@C1"0@
MB50D7`G(`[0D4`(``(M4)"2)7"14B?&+="0(@<'<O!N/B=,!P<'F!8GPBW0D
M"`^L_AL)\`'(,<F)1"08BT0D((E,)!R)P0^DPQ[!X1X/K-`"B=_!Z@*)S@G&
M"=>+1"10BU0D5(E\)$PQ_XET)$B)P8G3(?`A^@M,)$@+7"1,B7PD)"-,)`@C
M7"0,B70D((M\)!@)P0G3BT0D*`.$)%@"``"+5"0L$Y0D7`(``(ML)!P%W+P;
MCXG^@](``<&)^!'3#ZSN&S'2P>`%"?`!P8M$)`@1TXG*B4PD4#')B50D*(M4
M)`R)Q\'G'HE,)"R)U8GYB5PD5(G'#Z3%'@^LUP*)ZXG5B?[![0()SHM,)$B)
M[XET)'@)WS';"?&)7"1\BUPD3(G(BTPD("-$)!@)^XG:BUPD)"'Q(U0D'`G(
MBTPD6"'["=H#C"1@`@``BUPD7!.<)&0"``"!P=R\&X^#TP`!P1'3B4PD"(M,
M)"@QTHE<)`R+7"0LB<C!X`4/K-D;BUPD#`G(BTPD"`'!BT0D&!'3B<J)3"18
M,<F)5"1(BU0D'(E<)%R)3"1,B=.)P0^DPQ[!X1X/K-`"P>H""<$)TXM$)"`#
MA"1H`@``BU0D)!.4)&P"```%UL%BRHE,)`B#T@`QSHM,)%")7"0,B=<QVS'Q
MB<8!SHM,)$@1WXM<)$PQTHG(P>`%#ZS9&XM<)"P)R`'&$=<QR8G:B70D4(E,
M)%2+3"0HB70D<(ML)%2)R`^DRAZ)?"1TP>`>#ZS9`HG7B<;!ZP()S@G?B?"+
M="1X`[0D<`(``(GZB?&+?"1\BW0D"(E$)!@3O"1T`@``@<'6P6+*B50D'(G[
MBWPD4(/3`#'&BT0D6#'2,?")_@'!B?@1TP^L[ALQTL'@!0GP`<$1TXE,)%B)
MRC')B4PD+(M,)$B)5"0HB5PD7(M<)$R)R,'@'HMT)`B)VHG'BT0D<`^DRAX/
MK-D""<_!ZP*)U8E\)"`)W8N\)'@"``");"0DBZPD?`(``(''UL%BRH/5`(GY
M,?^)ZP'QBW0D&!'[,W0D((G/BTPD*#'PB=V+7"0L,=(!QXG($=4/K-D;B?Z+
M7"14P>`%,=*)[PG(BTPD4`'&$=<QTHG(B70D2(E4)$R)VL'@'@^DRAX/K-D"
MB70D<(NT)(0"``#!ZP*)U8E\)'2)QPG=BYPD@`(```G/BT0D6(E\)`B!P];!
M8LJ);"0,BVPD3(/6`(G9,?^)\XMT)!@!\8MT)"`1^XM\)$@S="0(,=(Q\`'!
MB?Z)^!'3#ZSN&S'2P>`%"?`!P1'3B4PD6(G*,<F)3"14BTPD*(E4)%")7"1<
MBUPD+(G(P>`>BW0D((G:B<>+1"1P#Z3*'@^LV0()S\'K`HN,)(@"``")U0G=
MBYPDC`(``(E\)!B!P=;!8LJ);"0<@],`,?\!\8MT)`@1^S-T)!B)SXM,)%`Q
M\(G=BUPD5#'2`<>)R!'5#ZS9&XG^BUPD3,'@!3'2B>\)R(M,)$@!QA'7,=*)
MR(ET)"B)5"0LB=K!X!X/I,H>#ZS9`HET)'"+M"24`@``P>L"B=6)?"1TB<<)
MW8N<))`"```)SXM$)%B)?"0@@</6P6+*B6PD)(ML)"R#U@")V3'_B?.+="0(
M`?&+="08$?N+?"0H,W0D(#'2,?`!P8G^B?@1TP^L[ALQTL'@!0GP`<$1TXE,
M)%B)RC')B4PD3(M,)%")5"1(B5PD7(M<)%2)R,'@'HMT)!B)VHG'BT0D<`^D
MRAX/K-D""<_!ZP*+C"28`@``B=4)W8N<))P"``")?"0(@<'6P6+*B6PD#(/3
M`#'_`?&+="0@$?LS="0(B<^+3"1(,?")W8M<)$PQT@''B<@1U0^LV1N)_HM<
M)"S!X`4QTHGO"<B+3"0H`<81US'2B<B)="10B50D5(G:P>`>#Z3*'@^LV0*)
M="1PB[0DI`(``,'K`HG5B7PD=(G'"=V+G"2@`@``"<^+1"18B7PD&('#UL%B
MRHEL)!R+;"14@]8`B=DQ_XGSBW0D(`'QBW0D"!'[BWPD4#-T)!@QTC'P`<&)
M_HGX$=,/K.X;,=+!X`4)\`'!$=.)3"18B<HQR8E,)"R+3"1(B50D*(E<)%R+
M7"1,B<C!X!Z+="0(B=J)QXM$)'`/I,H>#ZS9`@G/P>L"BXPDJ`(``(G5"=V+
MG"2L`@``B7PD(('!UL%BRHEL)"2#TP`Q_P'QBW0D&!'[,W0D((G/BTPD*#'P
MB=V+7"0L,=(!QXG($=4/K-D;B?Z+7"14P>`%,=*)[PG(BTPD4`'&$=<QTHG(
MB70D2(E4)$R)VL'@'@^DRAX/K-D"B70D<(NT)+0"``#!ZP*)U8E\)'2)QPG=
MBYPDL`(```G/BT0D6(E\)`B!P];!8LJ);"0,BVPD3(/6`(G9,?^)\XMT)!@!
M\8MT)"`1^XM\)$@S="0(,=(Q\`'!B?Z)^!'3#ZSN&S'2P>`%"?`!P1'3B4PD
M6(G*,<F)3"14BTPD*(E4)%")7"1<BUPD+(G(P>`>BW0D((G:B<>+1"1P#Z3*
M'@^LV0()S\'K`HN,)+@"``")U0G=BYPDO`(``(E\)!B!P=;!8LJ);"0<@],`
M,?\!\8MT)`@1^S-T)!B)SXM,)%`Q\(G=BUPD5#'2`<>)R!'5#ZS9&XG^BUPD
M3,'@!3'2B>\)R(M,)$@!QA'7,=*)R(ET)"B)5"0LB=K!X!X/I,H>#ZS9`HET
M)'"+M"3$`@``P>L"B=6)?"1TB<<)W8N<),`"```)SXM$)%B)?"0@@</6P6+*
MB6PD)(ML)"R#U@")V3'_B?.+="0(`?&+="08$?N+?"0H,W0D(#'2,?`!P8G^
MB?@1TP^L[ALQTL'@!0GP`<$1TXE,)%B)RC')B4PD3(M,)%")5"1(B5PD7(M<
M)%2)R,'@'HMT)!B)VHG'BT0D<`^DRAX/K-D""<_!ZP*+C"3(`@``B=4)W8N<
M),P"``")?"0(@<'6P6+*B6PD#(/3`#'_`?&+="0@$?LS="0(B<^+3"1(,?")
MW8M<)$PQT@''B<@1U0^LV1N)_HM<)"S!X`4QTHGO"<B+3"0H`<81US'2B<B)
M="10B50D5(G:P>`>#Z3*'@^LV0*)="1PB[0DU`(``,'K`HG5B7PD=(G'"=V+
MG"30`@``"<^+1"18B7PD&('#UL%BRHEL)!R+;"14@]8`B=DQ_XGSBW0D(`'Q
MBW0D"!'[BWPD4#-T)!@QTC'P`<&)_HGX$=,/K.X;,=+!X`4)\`'!$=.)3"18
MB<HQR8E,)"R+3"1(B50D*(E<)%R+7"1,B<C!X!Z+="0(B=J)QXM$)'`/I,H>
M#ZS9`@G/P>L"BXPDV`(``(G5"=V+G"3<`@``B7PD(('!UL%BRHEL)"2#TP`Q
M_P'QBW0D&!'[,W0D((G/BTPD*#'PB=V+7"0L,=(!QXG($=4/K-D;B?Z+7"14
MP>`%,=*)[PG(BTPD4`'&$=<QTHG(B70D2(E4)$R)VL'@'@^DRAX/K-D"B70D
M<(NT).0"``#!ZP*)U8E\)'2)QPG=BYPDX`(```G/BT0D6(E\)`B!P];!8LJ)
M;"0,BVPD3(/6`(G9,?^)\XMT)!@!\8MT)"`1^XM\)$@S="0(,=(Q\`'!B?Z)
M^!'3#ZSN&S'2P>`%"?`!P1'3B4PD>(G*,<F)3"14BTPD*(E4)%")7"1\BUPD
M+(G(P>`>BW0D((G:B<>+1"1P#Z3*'@^LV0()S\'K`HN,).@"``")U0G=BYPD
M[`(``(E\)!B!P=;!8LJ);"0<@],`,?\!\8MT)`@1^S-T)!@QTC'P`<$1TXG.
MBTPD4#'2B=^+7"14B<C!X`4/K-D;BUPD3`G(BTPD2`'&$=<QTHG(B70D6(E4
M)%R)VL'@'@^DRAX/K-D"B70D<(NT)/0"``#!ZP*)U8E\)'2)QPG=BYPD\`(`
M``G/BT0D>(E\)""!P];!8LJ);"0D@]8`B=DQ_XGSBW0D"`'QBW0D&!'[,W0D
M((M\)%PQTC'PBW0D6`'!B?`1TP^L_ALQTL'@!0GP`<$1TXE,)'B)RC')B4PD
M3(M,)%")5"1(B5PD?(M<)%2)R,'@'HG:B<>+1"08#Z3*'@^LV0()SXN,)/@"
M``#!ZP*)U0G=B7PD*(M\)""!P=;!8LJ+7"1,B6PD+`'!BT0D<#-\)"B+;"1D
M,?B+?"1<`<&)SHM,)$B)R`^LV1O!X`4)R`'&B?,Q]HET)`R+="18B5PD"(G[
MB?$/I/,>P>$>#ZS^`L'O`HGPB<Z+3"0@B?J)WPG&BT0D,`G7`X0D``,``(M<
M)`R)="08!=;!8LJ+="0HB7PD'`'(BTPD>#-T)!@Q\8G&`<Z+3"0(B<@/K-D;
MP>`%"<@!QC'_BT0D"`-$)#@QTHEU`(GNB7T$B44(B54,BWPD2(ML)$R)^,'@
M'@^L[P()^`-$)!`QTHE&$(M$)!B)5A0#1"1`,=*)1AB+1"0HB58<`T0D:#'2
MB48@B58DBX0D#`,``&4K!10```!U"X'$'`,``%M>7UW#Z#T%```NC;0F````
M`"Z-="8`4^@ZM?__@</^;0``@^P4:GSH:K'__\<``2-%9\=`!`````#'0`B)
MJ\WOQT`,`````,=`$/[<NIC'0!0`````QT`8=E0R$,=`'`````#'0"#PX=+#
MQT`D`````,=`*`````#'0"P`````QT`P`````,=`-`````#'0'@`````@\08
M6\,NC;0F`````"Z-="8`Z+#1__\%;VT``%575E.#["R+3"1(BWPD0(E$)!R+
M="1$B<N)R(E,)`B+3S#!^Q_!X`,#1RB)7"0,,=L[1RB)7"04BU\TB40D$(M$
M)!0;1RQS!H/!`8/3`(M$)!"+5"04C6\XB4<HBT0D"(E7+(M4)`P/K-`=P>H=
M`<B)1S"+1W@1VHE7-(7`#X4S`0``@WPD2#\/CG@!``"+1"1(C4C`B<J)3"00
MP>H&C5H!B50D",'C!@'SC70F`(L&@\9`B44`BT;$B44$BT;(B44(BT;,B44,
MBT;0B440BT;4B444BT;8B448BT;<B44<BT;@B44@BT;DB44DBT;HB44HBT;L
MB44LBT;PB44PBT;TB44TBT;XB44XBT;\B44\B?CHG]#__SG>=9.+5"0(BTPD
M$(G0P>`&*<&)3"1(@WPD2`1R48L#B4<XBT0D2(M4)$B+1`/\B405_(U'/(GJ
M@^#\*<(ITP-4)$B#XOR#^@1R$H/B_#')BS0+B30(@\$$.=%R\XM$)$B)1WB#
MQ"Q;7E]=PXUV`(M$)$B%P'3F#[8#B$<X]D0D2`)TV8M$)$B+5"1(#[=$`_YF
MB405_NO%C;0F`````+E`````*<$[3"1(#T],)$B#[`0!Z%&)3"005E"+7"0L
MZ'NN__^+3"08BT=X@\00`<B)1WB#^$!UC(GX*4PD2`'.Z+K/___I@O[__RZ-
M="8`B?/I(?___RZ-M"8`````D.B0S___!4]K``!55U93@^P<BUPD-(MT)#")
M1"0$BT,HBU,LC7LX#\B)1"0(BT,P#\B)Q8M#*`^LT`.)PH/B/XU"`<9$$SB`
M@_@X#XY``0``ND````"-#`<IPG0C,<#VP@%T#+@!````Q@$`.=!S$,8$`0#&
M1`$!`(/``CG0<O")V.@:S___C5<$QT,X`````#'`@^+\QT<T`````"G7C4\X
MB=?!Z0+SJXM$)`B):W")0W2)V.CGSO__BU,$BP.#[`P/K-`8B`:+4P2+`P^L
MT!"(1@&+`XAF`HL#B$8#BU,,BT,(#ZS0&(A&!(M3#(M#"`^LT!"(1@6+0PB(
M9@:+0PB(1@>+4Q2+0Q`/K-`8B$8(BU,4BT,0#ZS0$(A&"8M#$(AF"HM#$(A&
M"XM3'(M#&`^LT!B(1@R+4QR+0Q@/K-`0B$8-BT,8B&8.BT,8B$8/BU,DBT,@
M#ZS0&(A&$(M#((M3)`^LT!"(1A&+0R"(9A*+0R"(1A-3BUPD%.@QK/__@\0L
M6UY?7<,NC;0F`````)"Z.````"G"`?B#^@0/@HX```"-2`3'``````"#X?S'
M1!#\`````"G(`="#X/R#^`0/@N+^__^)Q[H$````@^?\B7PD#(UX_\'O`L<!
M`````(/G`3G"#X.]_O__A?]T&,=!!`````"+1"0,N@@````YP@^#H?[__XM$
M)`S'!!$`````QT01!`````"#P@@YPG+JZ8+^__\NC;0F`````&:0A=(/A'#^
M___&``#VP@(/A&3^__\Q_V:)?!#^Z5C^__]3Z#JP__^!P_YH``"#[`C_LR`!
M``#_="0<_W0D'/]T)!SHRJK__X/$&%O#9I!FD)!3Z`JP__^!P\YH``"#[`CH
M7*S__U.#[`CH\Z___X'#MV@``(/$"%O#````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O
M8R\E:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`
M4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]3
M4$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"
M04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D
M(&9A:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!4
M35``55-%4@!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R
M`'-H;W)T(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S
M=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N
M,#8R`"UE`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N86)L92!T;R!C<F5A=&4@8V%C:&4@
M9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````979A;"`G97AE
M8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T
M(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM
M>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE
M7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&
M24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M
M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS
M=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?
M<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@[
M"FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ
M93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?
M<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR
M96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)
M0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X]
M(#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE
M.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN
M9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N
M92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U0
M3$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P
M+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M
M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M
M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D
M9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA
M;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*
M<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%
M1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ
M<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I
M.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=
M*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-
M04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S
M("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N
M)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E
M("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*
M?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D
M;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R
M:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@
M34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M
M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U
M9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F
M)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@
M9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B
M)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S
M:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F
M9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L
M(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E
M<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68[
M"F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M
M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L
M(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I
M(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@
M)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@
M)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M
M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!
M4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F
M:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T
M92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H
M)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M
M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M
M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E
M('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO
M('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N
M86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@
M;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M
M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68[
M"G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A
M<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P
M:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$
M5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q
M6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H
M*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD
M968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT
M('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN
M960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N
M*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]
M"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM
M>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN
M97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@
M(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@
M;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD
M9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E
M9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@
M(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A
M7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@
M>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S
M=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE
M>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D
M8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV
M93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@
M)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G
M;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H
M<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N
M+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E
M>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6
M>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E
M('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P
M;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D
M;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#
M04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M
M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(
M12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C
M86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`]
M(")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D
M:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L*
M*&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@
M)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M
M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES
M>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L
M<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID
M96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@
M0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'
M3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]
M"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y]
M.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H
M*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN
M(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)
M3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W
M*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X
M<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I
M;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R
M.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG
M="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@
M;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G
M;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@
M)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PHQ.PI?7T5.1%]?"@``0T%#2$4``'!E<FQX<VDN8P````$;`SL0`0``(0``
M`+!?__]8`0``,&/__WP!``!`8___?`P``(!E__\L`0``L&;__Y`!``"09___
M"`(``"!H__]4`@``H&G__Q0#``#@:___E`,``+!L__\@!```$&W__W`$``!0
M;?__G`0``!!N__\L!0``(&[__T`%``!`</__/`8``(!P__]L!@``L''__^`&
M``"P=?__(`<``"!V__\\!P``8';__V0'``#`=___#`@``/!W__\X"```\'C_
M_[P(``#P?___0`L``/"!__\0#```M8+__\0,``"Y@O__V`P``,""___L#```
M<+#__S`-````L?__5`T``""S__^D#0``<+7___0-``"@M?__(`X``!0`````
M`````7I2``%\"`$;#`0$B`$'"!`````<````3&3__RP`````````%```````
M```!>E(``7P(`1L,!`2(`0``(````!P```!07O__@`,````."$8.#$H/"W0$
M>``_&CLJ,B0B$````$````"L8?__"`````````!T````5````!AE___<````
M`$$."(4"00X,AP-!#A"&!$$.%(,%3@XP`DD.-$$..$0./$$.0$@.,%D*#A1#
MPPX00<8.#$''#@A!Q0X$2`MT"@X40\,.$$'&#@Q!QPX(0<4.!$8+0PX40\,.
M$$/&#@Q!QPX(0<4.!`!(````S````(!E__^"`````$$."(8"0PX,@P-.#H@!
M40Z,`4$.D`%(#H`!80Z(`4(.C`%!#I`!2`Z``6(*#@Q!PPX(0<8.!$$+````
MO````!@!``#$9?__?@$```!!#@B%`D$.#(<#00X0A@1##A2#!5$.H`%L"@X4
M0<,.$$'&#@Q!QPX(0<4.!$D+0PZL`4$.L`%(#J`!20ZL`4$.L`%(#J`!:PZL
M`4$.L`%F#JP!1PZH`44.K`%!#K`!00ZT`4(.N`%"#KP!00[``4@.J`%%#JP!
M00ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.H`%##JP!00ZP`4@.H`%1
M#JP!00ZP`5`.H`$`?````-@!``"$9O__.`(```!!#@B%`D,.#(<#00X0A@1#
M#A2#!4X.3%<.4$@.0%H.3$,.4$P.0`).#DQ+#E!(#D`"9`H.%$'##A!!Q@X,
M0<<."$'%#@1)"P)D#DQ!#E!2#D!4#D1%#DA%#DQ!#E!4#D!9#DA!#DQ!#E!.
M#D````"(````6`(``$1H___.`````$$."(4"00X,AP-##A"&!$,.%(,%40[$
M(%0.R"!+#LP@00[0($@.P"!=#L0@00[(($$.S"!##M`@2`[`(%8*#A1!PPX0
M0<8.#$''#@A!Q0X$2PM+#L0@00[(($8.S"!!#M`@2`[`($\.Q"!!#L@@00[,
M($,.T"!(#L`@`$P```#D`@``B&C__UH`````00X(A@)!#@R#`TX.$$T.%$P.
M&$$.'$,.($8.'$<.&$(.'$$.($$.)$<.*$<.+$,.,$@.#$'##@A!Q@X$````
M*````#0#``"8:/__-@````!!#@B#`DX.$$<.%$P.&$$.'$D.($@."$'##@2,
M````8`,``*QH__^W`````$$."(4"0PX,AP-!#A"&!$$.%(,%40ZP0%<.N$!'
M#KQ`00[`0$<.Q$!%#LA`0@[,0$4.T$!(#K1`10ZX0$@.O$!!#L!`2`ZP0$<.
MO$!&#L!`2`ZP0$D.M$!!#KA`00Z\0$$.P$!-#K!`5@H.%$/##A!!Q@X,0<<.
M"$'%#@1!"P`0````\`,``-QH__\%`````````/@````$!```V&C__Q4"````
M00X(A0)!#@R'`T$.$(8$00X4@P51#K`A=0ZX(4(.O"%##L`A2`ZP(6T*#A1!
MPPX00<8.#$''#@A!Q0X$2`M##KPA00[`(48.O"%!#K@A2PZ\(4$.P"%(#K`A
M<`ZX(4$.O"%!#L`A2`ZP(4L.O"%!#L`A2`ZP(64.O"%!#L`A2`ZP(4D.O"%!
M#L`A3`ZP(5(.M"%!#K@A1`Z\(4$.P"%$#L0A10[((4(.S"%(#M`A2`ZX(40.
MO"%!#L`A2`ZP(5<.N"%$#KPA0@[`(4@.L"%]#K@A0@Z\(4$.P"%(#K`A5`Z\
M(4$.P"%(#K`A`"P`````!0``_&G__S(`````00X(A@)!#@R#`TX.&$8.'$$.
M(%@.#$'##@A!Q@X$`'`````P!0``#&K__R0!````00X(A0)!#@R'`T$.$(8$
M00X4@P51#K`@:@Z\($$.P"!(#K`@`DH.N"!"#KP@00[`($@.L"!.#KP@00[`
M($@.L"!6"@X40<,.$$'&#@Q!QPX(0<4.!$(+0PZ\($<.P"!(#K`@/````*0%
M``#(:O___`,```!!#@B%`D$.#(<#00X0A@1,#A2#!4,.0`.X`PH.%$?##A!!
MQ@X,0<<."$'%#@1%"Q@```#D!0``B&[__V$`````30X@`D8*#@1%"P`D````
M``8``-QN__\S`````$$."(,"3@X010X41`X82`X<0@X@````I````"@&``#T
M;O__6P$```!!#@B%`D$.#(<#0PX0A@1!#A2#!5$.P(`$50[$@`1"#LB`!$(.
MS(`$00[0@`1Z#L"`!%<.Q(`$00[(@`1!#LR`!$0.T(`$2`[`@`1.#L2`!$4.
MR(`$00[,@`1$#M"`!$@.P(`$`E8*#A1!PPX00<8.#$''#@A!Q0X$1@MK"@[,
M@`1'#M"`!$4+0PH.S(`$1P[0@`1%"P``*````-`&``"L;___*P````!!#@B#
M`DX.$$@.'$$.($@.$$D."$'##@0```"`````_`8``+!O___U`````$$."(4"
M00X,AP-!#A"&!$$.%(,%3@Y``D(*#A1#PPX00<8.#$''#@A!Q0X$1@M##DA!
M#DQ!#E!(#D!4"@X40<,.$$'&#@Q!QPX(0<4.!$L+0PY,00Y09`Y$20Y(00Y,
M1PY000Y40@Y80@Y<00Y@3`Y```"``@``@`<``"QP___Q!@```$$."(4"00X,
MAP-!#A"&!$$.%(,%40Z0`@+-#IP"00Z@`D@.D`)5#IP"00Z@`D@.D`)##IP"
M10Z@`D@.D`)B#IP"1PZ@`D$.I`)"#J@"0@ZL`D$.L`)/#I`"`D$.G`)!#J`"
M2`Z0`@)"#IP"00Z@`D8.G`)$#J`"9@ZD`D$.J`)+#JP"1PZP`D,.M`)"#K@"
M0@Z\`D$.P`)(#I@"10Z<`D$.H`)(#I`"6`Z8`D$.G`)$#J`"2`Z0`DD.G`)$
M#J`"1@ZD`D<.J`)*#JP"0@ZP`D@.D`):"@X40\,.$$'&#@Q!QPX(0<4.!$@+
M0PZ<`D0.H`)(#I`"`D\.G`)!#J`"5PZ0`DL.F`)!#IP"1@Z@`DP.D`)+#IP"
M1`Z@`D@.D`)*#I@"1PZ<`DT.H`)(#I`"`FH.E`)!#I@"2@Z<`D0.H`)!#J0"
M0@ZH`D(.K`)!#K`"2`Z0`F4.G`)!#J`"00ZD`D$.J`)$#JP"1`ZP`D0.M`)"
M#K@"0@Z\`D$.P`)(#I`"0PZ8`D4.G`)!#J`"2`Z0`D@.G`)$#J`"6PZ0`@)4
M#IP"2`Z@`D@.D`)6#IP"00Z@`D@.D`)."@Z8`D$.G`)$#J`"1@ZD`E,+0PZ<
M`D$.H`)8#I`"9PZ8`D(.G`)$#J`"2`Z0`F8.E`)$#I@"00Z<`D4.H`),#I0"
M0@Z8`D@.G`)%#J`"3`Z0`G`.E`)/#I@"00Z<`D$.H`),#I0"0@Z8`D@.G`)%
M#J`"2`Z0`E@.E`)'#I@"1`Z<`D0.H`)!#J0"0@ZH`D(.K`)!#K`"2`Z0`E<.
MG`)!#J`"3`Z0`DP.F`)'#IP"20Z@`D@.D`)<#IP"1PZ@`LP````$"@``J'3_
M__\!````00X(A0)!#@R'`T$.$(8$00X4@P5.#C`"2@XT0@XX00X\00Y`2`XP
M20XT1PXX10X\0PY`2PXP5`XT0@XX00X\0PY`2`XP7@XT00XX10X\0PY`2`XP
M0PXT2`XX00X\0PY`2`XT1PXX00X\0PY`7`XP3PXX10X\00Y`2`XP90H.%$'#
M#A!!Q@X,0<<."$'%#@1("T,*#CQ&#D!(#C!/#CQ'#D!)"WL..$$./$,.0$@.
M,$8*#C1'#CA"#CQ'#D!%"P!H````U`H``-AU___%`````$$."(<"00X,A@-!
M#A"#!$X.(`)."@X00<,.#$'&#@A!QPX$1@M##BQ!#C!(#BQ!#BA"#BQ!#C!8
M#B1(#BA!#BQ!#C!(#B!4"@X00\,.#$'&#@A!QPX$10L```!$````0`L``+Q6
M__\T`@```$0,`0!)$`4"=0!!$`<"=7Q$$`8"=7@0`P)U=$P/`W5P!@-?`0K!
M#`$`0<-!QD''0<5##`0$00L0````B`L``.EU__\$`````````!````"<"P``
MV77__P0`````````0````+`+``#,=?__HRT```!!#@B%`D$.#(<#0PX0A@1!
M#A2#!48.L`8#C2T*#A1!PPX00<8.#$''#@A!Q0X$00L````@````]`L``#BC
M__^#`````$$."(,"3@X<0@X@`G`."$'##@1,````&`P``*2C__\7`@```$L.
M"(4"00X,AP-!#A"&!$$.%(,%0PY``W<!"@X40<,.$$'&#@Q!QPX(0<4.!$0+
M`D,.1$,.2$4.3$$.4%,.0$P```!H#```=*7__U`"````2PX(A0)!#@R'`T$.
M$(8$00X4@P5##C`"L`X\`K4.0$P.%$'##A!!Q@X,0<<."$'%#@1*#C"#!84"
MA@2'`P``*````+@,``!TI___*P````!!#@B#`DX.$$8.%$0.&$0.'$0.($@.
M"$'##@08````Y`P``'BG__\4`````$$."(,"3@X0````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````$"<``,`F```!````^@(```$````*`P``#``````@```-````)'8`
M`!D```#<W0``&P````0````:````X-T``!P````$````]?[_;^P!```%````
MS`@```8```#,`@``"@```)X$```+````$````!4``````````P```.3>```"
M````N`$``!0````1````%P```%0/```1````S`X``!(```"(````$P````@`
M```>````"````/O__V\!```(_O__;RP.``#___]O`0```/#__V]J#0``^O__
M;P4`````````````````````````````````````````````````````````
MY-T`````````````-B```$8@``!6(```9B```'8@``"&(```EB```*8@``"V
M(```QB```-8@``#F(```]B````8A```6(0``)B$``#8A``!&(0``5B$``&8A
M``!V(0``AB$``)8A``"F(0``MB$``,8A``#6(0``YB$``/8A```&(@``%B(`
M`"8B```V(@``1B(``%8B``!F(@``=B(``(8B``"6(@``IB(``+8B``#&(@``
MUB(``.8B``#V(@``!B,``!8C```F(P``-B,``$8C``!6(P``9B,``'8C``"&
M(P``EB,`````````````````````````````````````````````````````
M`````````````+`C````````!.````I005(N<&T*`````.R"``!'0T,Z("A$
M96)I86X@,3,N,BXP+3$X*2`Q,RXR+C```"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN
M9'EN`"YR96PN<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````
M``````````````````````````````````````````L````!`````@```)0!
M``"4`0``$P```````````````0`````````3````!P````(```"H`0``J`$`
M`"0```````````````0`````````)@````<````"````S`$``,P!```@````
M```````````$`````````#0```#V__]O`@```.P!``#L`0``X`````4`````
M````!`````0````^````"P````(```#,`@``S`(````&```&`````0````0`
M```0````1@````,````"````S`@``,P(``">!``````````````!````````
M`$X```#___]O`@```&H-``!J#0``P`````4``````````@````(```!;````
M_O__;P(````L#@``+`X``*`````&`````0````0`````````:@````D````"
M````S`X``,P.``"(````!0`````````$````"````',````)````0@```%0/
M``!4#P``N`$```4````6````!`````@```!\`````0````8`````(````"``
M`"````````````````0`````````=P````$````&````("```"`@``"``P``
M```````````0````!````((````!````!@```*`C``"@(P``"```````````
M````"`````@```"+`````0````8```"P(P``L",``'12`````````````!``
M````````D0````$````&````)'8``"1V```4```````````````$````````
M`)<````!`````@````"`````@```;D``````````````!`````````"?````
M`0````(```!PP```<,```!0!``````````````0`````````K0````$````"
M````A,$``(3!```L#0`````````````$`````````+<````.`````P```-S=
M``#<W0``!```````````````!`````0```##````#P````,```#@W0``X-T`
M``0```````````````0````$````SP````8````#````Y-T``.3=`````0``
M!@`````````$````"````(8````!`````P```.3>``#DW@``'`$`````````
M````!`````0```#8`````0````,`````X````.```!@```````````````0`
M````````W@````@````#````&.```!C@```4```````````````$````````
M`.,````!````,``````````8X```'P```````````````0````$````!````
D`P``````````````-^```.P```````````````$`````````
